@@ -1,5 +1,5 @@
 "ickde" <-
-function (I, h, f, m, n.iterations = 10, x1, xm, right.limit = 10000) 
+function (I, h, f, m, n.iterations = 10, x1, xm, right.limit = 10000, kernel="gaussian") 
 {
     if (missing(x1)) 
         x1 <- min(I) - 4 * h
@@ -20,11 +20,12 @@ function (I, h, f, m, n.iterations = 10, x1, xm, right.limit = 10000)
     f0 <- f
     niter <- n.iterations
     f1 <- f
+    ker <- which(c("gaussian", "epanechnikov", "biweight") %in% kernel)
     z <- .Fortran("ickde", as.integer(n), as.double(left), as.double(right), 
         as.integer(numgrid), as.double(gridpts), as.double(f0), 
-        as.double(h), as.integer(niter), as.double(f1), PACKAGE = "ICE")
+        as.double(h), as.integer(niter), as.double(f1), as.integer(ker), PACKAGE = "ICE")
     names(z) <- c("n", "left", "right", "numgrid", "x", "f0", 
-        "h", "niter", "y")
+        "h", "niter", "y", "ker")
     z.out <- list(x = z$x, y = z$y)
     class(z.out) <- "IC"
     z.out
